@@ -1,5 +1,6 @@
-from .core import APIManager
+from .core import APIConfig as SellerAPIConfig
 from .methods import (
+    SellerBetaAPI,
     SellerBarcodeAPI,
     SellerCategoryAPI,
     SellerFBSAPI,
@@ -10,6 +11,7 @@ from .methods import (
 
 
 class SellerAPI(
+    SellerBetaAPI,
     SellerBarcodeAPI,
     SellerCategoryAPI,
     SellerFBSAPI,
@@ -24,6 +26,6 @@ class SellerAPI(
     pass
 
 
-__all__ = ["SellerAPI", "APIManager"]
+__all__ = ["SellerAPI", "SellerAPIConfig"]
 
 # Импортируйте здесь бизнес-методы и собирайте публичный API
