@@ -2,20 +2,23 @@
 https://docs.ozon.ru/api/seller/?__rr=1#tag/CategoryAPI
 """
 __all__ = [
+    "DescriptionCategoryAttributeItem",
     "DescriptionCategoryAttributeRequest",
     "DescriptionCategoryAttributeResponse",
     "DescriptionCategoryAttributeValuesRequest",
     "DescriptionCategoryAttributeValuesResponse",
     "DescriptionCategoryAttributeValuesSearchRequest",
     "DescriptionCategoryAttributeValuesSearchResponse",
+    "DescriptionCategoryTreeItem",
     "DescriptionCategoryTreeRequest",
     "DescriptionCategoryTreeResponse",
 ]
 
-from .v1__description_category_attribute import DescriptionCategoryAttributeRequest, \
-    DescriptionCategoryAttributeResponse
+from .v1__description_category_attribute import DescriptionCategoryAttributeItem, \
+    DescriptionCategoryAttributeRequest, DescriptionCategoryAttributeResponse
 from .v1__description_category_attribute_values import DescriptionCategoryAttributeValuesRequest, \
     DescriptionCategoryAttributeValuesResponse
 from .v1__description_category_attribute_values_search import DescriptionCategoryAttributeValuesSearchRequest, \
     DescriptionCategoryAttributeValuesSearchResponse
-from .v1__description_category_tree import DescriptionCategoryTreeRequest, DescriptionCategoryTreeResponse
+from .v1__description_category_tree import DescriptionCategoryTreeItem, DescriptionCategoryTreeRequest, \
+    DescriptionCategoryTreeResponse
\ No newline at end of file
