@@ -23,8 +23,14 @@ __all__ = [
     "PostingFBSProductChangeRequest",
     "PostingFBSProductChangeRequestItem",
     "PostingFBSProductChangeResponse",
+    "PostingFBSProductCountrySetRequest",
+    "PostingFBSProductCountrySetResponse",
     "PostingFBSProductDetailed",
+    "PostingFBSProductCountryListRequest",
+    "PostingFBSProductCountryListResponse",
     "PostingFBSRequirements",
+    "PostingFBSRestrictionsRequest",
+    "PostingFBSRestrictionsResponse",
     "PostingFBSTariffication",
     "PostingFBSListRequestFilterLastChangedStatusDate",
     "PostingFBSListFilter",
@@ -45,9 +51,13 @@ from .entities import PostingFBSAddressee, PostingFBSAnalyticsData, PostingFBSBa
     PostingFBSFinancialDataProducts, PostingFBSLegalInfo, PostingFBSOptional, PostingFBSPosting, \
     PostingFBSProductDetailed, \
     PostingFBSRequirements, PostingFBSTariffication, PostingFBSFilterWith, PostingFBSProduct
+from .v1__posting_fbs_restrictions import PostingFBSRestrictionsResponse, PostingFBSRestrictionsRequest
 from .v2__posting_fbs_get_by_barcode import PostingFBSGetByBarcodeRequest, PostingFBSGetByBarcodeResponse
 from .v2__posting_fbs_product_change import PostingFBSProductChangeRequestItem, PostingFBSProductChangeRequest, \
     PostingFBSProductChangeResponse
+from .v2__posting_fbs_product_country_list import PostingFBSProductCountryListResponse, \
+    PostingFBSProductCountryListRequest
+from .v2__posting_fbs_product_country_set import PostingFBSProductCountrySetResponse, PostingFBSProductCountrySetRequest
 from .v3__posting_fbs_get import PostingFBSGetRequest, PostingFBSGetResponse
 from .v3__posting_fbs_list import PostingFBSListRequestFilterLastChangedStatusDate, \
     PostingFBSListFilter, PostingFBSListRequest, PostingFBSListResult, PostingFBSListResponse
